import { FC } from "react"
import Style from './style/Banner.module.less'
import { motion, Variants } from "framer-motion"

export interface BannerProps {
  src?: string;
  titleTop?: string;
  titleBottom?: string;
}

export const Banner: FC<BannerProps> = (props) => {

  const {
    src = 'https://webapi.huajulaw.com/Data/banner/2023-10-20/ccd96051-d7ba-4626-a7a2-f7bd18727c78.jpeg',
    titleTop,
    titleBottom,
  } = props

  const item: Variants = {
    hidden: {
      y: 50,
      opacity: 0,
    },
    visible: {
      y: 0,
      opacity: 1,
      transition: {
        duration: 0.8
      }
    },
  };

  return (
    <div className={Style.bitzBannerBlock}>
      <img
        src={src}
        className={Style['banner-img']}
      />
      <div className={Style['benner-line']}>
        <motion.div
          className={Style['left-con']}
          initial="hidden"
          animate="visible"
          transition={{
            staggerChildren: 0.3,
            delayChildren: 0.3
          }}
        >
          {
            titleTop && <motion.div variants={item} className={Style['tit-top']}>{titleTop}</motion.div>
          }
          {
            titleBottom && <motion.div variants={item} className={Style['tit-bottom']}>{titleBottom}</motion.div>
          }
        </motion.div>
      </div>
    </div>
  )
}

export default Banner
