import {FC, useRef} from 'react'
import {motion, Variants} from "framer-motion";
import Style from "./style/Carousel.module.less";
import { Swiper, SwiperSlide } from "swiper/react";
import { Autoplay } from 'swiper/modules'

export interface Item {
  img?: string;
  title?: string;
  des?: string;
}

export interface CarouselProps {
  items?: Item[];
  once?: boolean;
  autoplay?: boolean;
}

const Carousel: FC<CarouselProps> = (props) => {
  const {
    items,
    once,
    autoplay
  } = props
  const ref = useRef(null);

  const item: Variants = {
    hidden: {
      y: 50,
      opacity: 0,
    },
    visible: {
      y: 0,
      opacity: 1,
      transition: {
        duration: 0.8
      }
    },
  };

  return (
    <div className={Style['BitzBanner1-contianer']}>
      <Swiper
        ref={ref}
        modules={[Autoplay]}
        className={Style.mySwiper}
        onSwiper={(swiper: any) => console.log(swiper)}
        loop
        autoplay={autoplay}
      >
        {
          items?.map((v, key) => (
            <SwiperSlide key={key} className={Style['swiper-item']}>
              <img src={v.img} className={Style['swiper-item-img']} />
              <motion.div
                initial="hidden"
                whileInView="visible"
                transition={{
                  staggerChildren: 0.3,
                  // delayChildren: 0.3
                }}
                viewport={{
                  once: once, // 是否重复执行
                  root: ref,
                }}
                className={Style['swiper-item-content']}
              >
                {
                  v?.title && <motion.div variants={item}>{v.title}</motion.div>
                }
                {
                  v.des && <motion.div variants={item}>{v.des}</motion.div>
                }
              </motion.div>
            </SwiperSlide>
          ))
        }
      </Swiper>
    </div>
  )
}

export default Carousel
