import { FC, useEffect, useMemo, useState } from "react";
import { useRouter } from "next/router";
import BitzLogo from "@/components/BitzLogo";
import IconFont from "@/assets/iconfont";
import Search from "./Search";
import BitzLanguage from "@/components/BitzLanguage";
import styles from "./index.module.less";
import Link from "next/link";

interface BitzHeaderProps {
  /**
   * nav的position类型
   */
  position?: any;
  /**
   * nav的高度
   */
  height?: any;
  /**
   * nav的菜单数据
   */
  navData?: any[];
  /**
   * 是否显示搜索框
   */
  showSearch?: boolean;
}

const BitzHeader: FC<BitzHeaderProps> = ({
  position = "relative",
  height = "4rem",
  navData = [],
  showSearch = false,
}) => {
  const router = useRouter();
  const pathname = router?.pathname;

  const handleNav = (item: any) => {
    setIsToggle(false);
  };

  const selectIndex = useMemo(() => {
    if (pathname == "/") {
      return 0;
    } else {
      const Index = navData.findIndex((item: any) => {
        return `/${item.key}` == pathname;
      });
      return Index;
    }
  }, [pathname]);

  const [isToggle, setIsToggle] = useState<boolean>(false);

  /**
   * @description 选择itemIndex
   */
  const [itemInex, setItemIndex] = useState<number>(-1);

  /**
   * nav内容
   */

  const navHtml = () => {
    return (
      <>
        {navData.map((item: any, index: number) => {
          return (
            <div
              style={{
                color: `${selectIndex == index ? "red" : ""}`,
              }}
              className={styles.item}
              key={index}
              onClick={() => {
                handleNav(item);
              }}
              onMouseOver={() => {
                setItemIndex(index);
              }}
            >
              <Link href={item.key}>
                {item.name}
                {item.children && (
                  <div
                    onMouseLeave={() => {
                      setItemIndex(-1);
                    }}
                    style={{ height: `${itemInex == index ? "200px" : "0"}` }}
                    className={styles.itemHideBox}
                  ></div>
                )}
              </Link>
            </div>
          );
        })}
      </>
    );
  };

  /**
   * @description language内容
   */

  const [isSearch, setIsSearch] = useState<boolean>(false);
  const languageHtml = () => {
    return (
      <div className={styles.languageBox}>
        {showSearch && (
          <IconFont
            className={styles.searchBtn}
            onClick={() => {
              setIsToggle(false);
              setIsSearch(!isSearch);
            }}
            color="#333"
            size={24}
            name="chazhao"
          />
        )}

        <BitzLanguage
          lang={router.locale}
          changeEmit={(val) => {
            const Language = val;
            const { pathname, asPath, query } = router;
            router.push({ pathname, query }, asPath, { locale: Language });
          }}
        />
      </div>
    );
  };

  /**
   * @description 查找内容
   */

  useEffect(() => {
    if (isSearch) {
      document.body.style.overflow = "hidden";
    } else {
      document.body.style.overflow = "auto";
    }
  }, [isSearch]);

  useEffect(() => {
    if (isToggle) {
      document.body.style.overflow = "hidden";
    } else {
      document.body.style.overflow = "auto";
    }
  }, [isToggle]);

  return (
    <div
      style={{ position: position, height: height }}
      className={styles.bitzHeaderBlock}
    >
      <BitzLogo />
      <Search top={height} isSearch={isSearch} />
      <div className={styles.navBox}>{navHtml()}</div>
      {languageHtml()}
      <div
        className={styles.toggleBox}
        onClick={() => {
          setIsSearch(false);
          setIsToggle(!isToggle);
        }}
      >
        {!isToggle && <IconFont color="#333" size={24} name="qiehuanlie" />}
        {isToggle && (
          <IconFont
            className={styles.toggleBtn}
            onClick={() => {
              setIsToggle(!isToggle);
            }}
            color="#333"
            size={24}
            name="close"
          />
        )}
      </div>
      <div
        style={{ height: `${isToggle ? "100%" : "0"}` }}
        className={styles.mobilePage}
      >
        <div className={styles.mobileCenter}>{navHtml()}</div>
      </div>
    </div>
  );
};

export default BitzHeader;
