import {FC, useEffect, useState} from "react"
import Style from './index.module.less'
import cx from 'classnames'
import { GetVerificationCode } from "@/services/Expand";
import { useForm } from 'react-hook-form';
import {CreateSiteMessage} from "@/services/SiteMessage";
import { message } from "antd";
import { useTranslation } from 'next-i18next'

interface formType {
  name?: string
  phone?: string
  email?: string
  contnet?: string
  verificationCode: {
    code: string
    codeId: string
  },
  status: string
}

const BitzMessage: FC = () => {
  const { t } = useTranslation();
  const [messageApi, contextHolder] = message.useMessage();
  const {
    register,
    handleSubmit,
    formState: { errors },
    setValue,
    reset
  } = useForm<formType>();


  const [codeImg, setCodeImg] = useState()


  const getVerificationCode = async () => {
    const data = await GetVerificationCode()
    const { codeId, imgBase } = data.data
    setCodeImg(imgBase)
    // setForm((draft) => {
    //   draft.verificationCode.codeId = codeId
    // })
    setValue('verificationCode.codeId', codeId)
  }

  const onSubmit = async (data: any) => {
    const res = await CreateSiteMessage({
      ...data,
      status: 'N'
    })
    if (res.status !== 200) {
      messageApi.open({
        type: 'error',
        content: '',
      });
      return
    }
    messageApi.open({
      type: 'success',
      content: '',
    });
    reset()
    await getVerificationCode()
  }

  useEffect(() => {
    getVerificationCode()
  }, [])

  const renderMessage = (name: string) => {
    // @ts-ignore
    if (errors[name]) {
      // @ts-ignore
      return <div
        style={{ color: 'red' }}
        className="text-sm mt-2 mb-4"
        // @ts-ignore
      >*{errors[name]?.message}</div>
    }
    return null
  }

  return (
    <div className={Style.bitzFooterBlock}>
      <form onSubmit={handleSubmit(onSubmit)}>
        <div className={cx(Style.container)}>
          <div className={Style.Item}>
            <input
              {...register("name", {
                required: t('Web_EnterName'),
                maxLength: 80
              })}
              placeholder={ t('Web_EnterName')}
              type="text"
              className={Style.input}
            />
            {renderMessage('name')}
          </div>
          <div className={Style.Item}>
            <input
              {...register("phone", {
                required: t('Web_EnterPhone'),
                maxLength: 80,
                pattern: {
                  value:  /^((0\d{2,3}-\d{7,8})|(1[3456789]\d{9}))$/,
                  message: t('Web_EnterTruePhone', '请输入正确的电话')
                }
              })}
              placeholder={t('Web_EnterPhone')}
              type="text"
              className={Style.input}
            />
            {renderMessage('phone')}
          </div>
          <div className={Style.Item}>
            <input
              {...register("email", {
                required: t('Web_EnterEmail'),
                maxLength: 80,
                pattern: {
                  value: /^\w+@[a-z0-9]+\.[a-z]{2,4}$/,
                  message: t('Web_EnterTrueEmail', '请输入正确的邮箱')
                }
              })}
              placeholder={t('Web_EnterEmail')}
              type="text"
              className={Style.input}
            />
            {renderMessage('email')}
          </div>
          <div className={cx(Style.Item)}>
            <div className="flex justify-between items-center">
              <input
                {...register("verificationCode.code", {
                  required: t('Web_EnterCode', '请输入验证码'),
                  maxLength: 80
                })}
                placeholder={t('Web_EnterCode', '请输入验证码')}
                type="text"
                className={Style.input}
              />
              {
                codeImg && (
                  <div className="flex-shrink-0 ml-6 cursor-pointer">
                    <img
                      alt=""
                      onClick={getVerificationCode}
                      src={`data:image/jpeg;base64,${codeImg}`}
                    />
                  </div>
                )
              }
            </div>
            {
              errors?.verificationCode?.code && (
                <div
                  style={{ color: 'red' }}
                  className="text-sm mt-2 mb-4"
                >*{errors?.verificationCode?.code?.message}</div>
              )
            }
          </div>
          <div className="md:col-span-2">
            <textarea
              {...register("contnet", {
                required: t('Web_EnterContent', '请输入咨询内容'),
                maxLength: 1000
              })}
              placeholder={t('Web_EnterContent', '请输入咨询内容')}
              className={Style.textarea}
            />
            {renderMessage('contnet')}
          </div>
          <div className="md:col-span-2 mx-auto">
            <button type="submit" className={Style["btn-submit"]}>{t('System_Message', '留言')}</button>
          </div>
        </div>
      </form>
    </div>
  )

}

export default BitzMessage
