import { FC } from "react";
import NextLink from 'next/link'
import {usePagination, PaginationItemType, PaginationItemValue} from "@nextui-org/use-pagination"
import type { UsePaginationProps } from "@nextui-org/use-pagination"
import cx from 'classnames'

import Style from './index.module.less'


export interface BitzPagination2Props extends UsePaginationProps {
  href?: (page: number) => string;
}

const BitzPagination2: FC<BitzPagination2Props> = (props) => {
  const { href, ...rest } = props

  const {activePage, range, setPage, next, previous} = usePagination(rest);

  const Component = href ? NextLink : 'li'

  const getBaseProps = (type: PaginationItemValue ) => {
    console.log('type', type)
    if (href) {
      if (type === PaginationItemType.NEXT) {
        if (props.total === activePage) {
          return {
            href: '#'
          }
        }
        return {
          href: href?.(activePage + 1),
          // disabled:  activePage
        }
      }
      if (type === PaginationItemType.PREV) {
        if (activePage === 1) {
          return {
            href: '#'
          }
        }
        return {
          href: href?.(activePage - 1),
        }
      }

      return {
        href: href?.(typeof type === "number" ? type : 0)
      }
    }

    return {
      href: '#'
    }
  }

  return (
    <ul className={cx("flex items-center text-sm", Style.bitzPage)}>
      {range.map((page) => {
        if (page === PaginationItemType.NEXT) {
          return (
            <Component
              style={{width: '80px'}}
              key={page}
              aria-label="next page"
              onClick={next}
              {...getBaseProps(page)}            >
              下一页
            </Component>
          );
        }

        if (page === PaginationItemType.PREV) {
          return (
            <Component
              style={{ width: '80px' }}
              key={page}
              aria-label="previous page"
              onClick={previous}
              {...getBaseProps(page)}
            >
              上一页
            </Component>
          );
        }

        if (page === PaginationItemType.DOTS) {
          return ''
          // return (
          //   <li key={page} className="w-8 h-8">
          //     ...
          //   </li>
          // );
        }

        return (
          <Component
            key={page}
            aria-label={`page ${page}`}
            className={cx(activePage === page && Style['pagination_active'])}
            onClick={() => setPage(page)}
            {...getBaseProps(page)}
          >
            {page}
          </Component>
        );
      })}
    </ul>
  )
}

export default BitzPagination2
