import { FC } from "react";
import { useRouter } from "next/router";
import { Button } from "antd";
import Link from "next/link";
import styles from "./index.module.less";
import { useTranslation } from "next-i18next";

interface BitzPreviousNextProps {
  /**
   * 详情数据
   */
  infoData?: any;
  /**
   * 返回页面的Url
   */
  url?: string;
}

const BitzPreviousNext: FC<BitzPreviousNextProps> = ({
  infoData = {},
  url = "",
}) => {
  const { t } = useTranslation();
  const router = useRouter();

  const handleBack = () => {
    router.push(`/${url}`);
  };

  return (
    <div className={styles.bitzPreviousNextBlock}>
      <div className={styles.backContent}>
        <div className={styles.row}>
          <div className={styles.rowLeft}>{t("Web_Prev", "上一篇")}：</div>
          <div className={styles.rowRight}>
            {
              infoData?.prevArticle?.item?.name&&(<Link
                href={`/news/${infoData?.prevArticle?.id}`}
              >
                {infoData?.prevArticle?.item?.name}
              </Link>)
            }
            {
              !(infoData?.prevArticle?.item?.name)&&(<>{t("Web_Nothing", "无")}</>)
            }
          </div>
        </div>
        <div className={styles.row}>
          <div className={styles.rowLeft}>{t("Web_Next", "下一篇")}：</div>
          <div className={styles.rowRight}>
            {
              infoData?.nextArticle?.item?.name&&(<Link
                href={`/news/${infoData?.nextArticle?.id}`}
              >
                {infoData?.nextArticle?.item?.name }
              </Link>)
            }
            {
              !(infoData?.nextArticle?.item?.name)&&(<>{t("Web_Nothing", "无")}</>)
            }
          </div>
        </div>
      </div>
      <Link href={`/${url}`}>
        <div className={styles.backBtn}>{t("Web_Back", "返回列表")}</div>
      </Link>
    </div>
  );
};

export default BitzPreviousNext;
