import styles from "./index.module.less";
import { FC, useState, useEffect, useRef } from "react";
import { DownOutlined } from "@ant-design/icons";
import { gsap } from "gsap";

interface BitzSelect {
  placeholder?: string | number;
  value?: string | number;
  options?: { label: string; value: string | number }[];
  onChange?: (
    value?: string | number,
    item?: { label: string; value: string | number }
  ) => void;
}

const BitzSelect: FC<BitzSelect> = ({
  placeholder = "请选择",
  value,
  options,
  onChange,
}) => {
  const ref = useRef<HTMLDivElement>(null);
  const ulRef = useRef<HTMLUListElement>(null);
  const iconRef = useRef<HTMLUListElement>(null);
  const [ctx, setCtx] = useState({
    open: false,
    value,
  });

  useEffect(() => {
    onChange?.(ctx.value, options?.find((item) => item.value === ctx.value));
  }, [ctx.value]);

  useEffect(() => {
    function clickBody(e: MouseEvent) {
      if (!ref.current?.contains(e.target as any)) {
        setCtx((prev) => ({
          ...prev,
          open: false,
        }));
      }
    }
    document.body.addEventListener("click", clickBody);
    return () => {
      document.body.removeEventListener("click", clickBody);
    };
  }, []);

  useEffect(() => {
    if (ctx.open) {
      gsap.to(ulRef.current, {
        y: 0,
        opacity: 1,
        height: "auto",
      });
      gsap.to(iconRef.current, {
        rotate: 180,
      });
    } else {
      gsap.to(ulRef.current, {
        y: -10,
        opacity: 0,
        height: 0,
      });
      gsap.to(iconRef.current, {
        rotate: 0,
      });
    }
  }, [ctx.open]);

  function renderOptions() {
    return (
      <ul
        className={`${styles.scrollbar} mt-2 w-full max-h-60 opacity-0 overflow-y-scroll absolute z-10 shadow-round `}
        ref={ulRef}
      >
        {!!options?.length &&
          options.map((item, index) => (
            <li
              key={index}
              className="p-2 bg-white cursor-pointer text-ellipsis overflow-hidden whitespace-nowrap w-full transition-all duration-500 hover:bg-red-700 hover:text-white"
              onClick={() => {
                setCtx((prev) => ({
                  ...prev,
                  value: item.value,
                  open: false,
                }));
              }}
            >
              {item.label}
            </li>
          ))}
      </ul>
    );
  }

  return (
    <div className="bitzSelectBlock w-full text-left relative" ref={ref}>
      <div
        className="cursor-pointer w-full bg-gray-50 rounded-full text-ellipsis overflow-hidden whitespace-nowrap p-4 min-h-20 "
        onClick={() => {
          setCtx((prev) => ({
            ...prev,
            open: !prev.open,
          }));
        }}
      >
        {ctx.value === ""
          ? placeholder
          : options?.find((item) => item.value === ctx.value)?.label ||
            placeholder}
        <DownOutlined
          ref={iconRef}
          className="absolute right-4 top-1/2 -translate-y-1/2 text-gray-400"
        />
      </div>
      {renderOptions()}
    </div>
  );
};

export default BitzSelect;
